@@ -446,6 +446,7 @@ const inputSourceContainerTemplate = `{{- define "inputSourceContainerTemplate"
   rotate_wait 5
   tag kubernetes.*
   read_from_head "true"
+  skip_refresh_on_startup true
   @label @MEASURE
   <parse>
     @type multi_format
@@ -472,6 +473,7 @@ const inputSourceHostAuditTemplate = `{{- define "inputSourceHostAuditTemplate"
   @label @MEASURE
   path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
   pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
+  refresh_interval 5
   tag linux-audit.log
   <parse>
     @type viaq_host_audit
@@ -487,6 +489,7 @@ const inputSourceK8sAuditTemplate = `{{- define "inputSourceK8sAuditTemplate" -}
   @label @MEASURE
   path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
   pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
+  refresh_interval 5
   tag k8s-audit.log
   <parse>
     @type json
@@ -506,6 +509,7 @@ const inputSourceOpenShiftAuditTemplate = `{{- define "inputSourceOpenShiftAudit
   @label @MEASURE
   path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
   pos_file /var/log/oauth-apiserver.audit.log
+  refresh_interval 5
   tag openshift-audit.log
   <parse>
     @type json
@@ -734,16 +738,8 @@ tls_cert_path "{{$path}}"
   @type file
   path '{{.BufferPath}}'
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
-{{- else }}
-  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
-{{- end }}
   flush_mode {{.FlushMode}}
   flush_interval {{.FlushInterval}}
   flush_at_shutdown true
@@ -811,16 +807,8 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
-{{- else }}
-    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end}}
-{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -895,16 +883,8 @@ const storeSyslogTemplate = `{{- define "storeSyslog" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
-{{- else }}
-    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -937,16 +917,8 @@ ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
   retry_max_interval {{.RetryMaxInterval}}
   retry_forever true
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
-{{- else }}
-  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
   overflow_action {{.OverflowAction}}
 </buffer>
 {{- end}}
